<?php

namespace Drupal\viewsreference_filter;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\views\ViewExecutableFactory;
use Psr\Log\LoggerInterface;

/**
 * The Views Reference Filter Utility Class.
 */
class ViewsRefFilterUtility implements ViewsRefFilterUtilityInterface {

  /**
   * A LoggerChannelInterface viewsreference_filter.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The views executable factory.
   *
   * @var \Drupal\views\ViewExecutableFactory
   */
  protected $viewsExecutableFactory;

  /**
   * Constructs a new ViewsRefFilterUtility object.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   A LoggerChannelInterface viewsreference_filter.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\views\ViewExecutableFactory $viewsExecutableFactory
   *   The views executable factory.
   */
  public function __construct(LoggerInterface $logger, EntityTypeManagerInterface $entity_type_manager, ViewExecutableFactory $viewsExecutableFactory) {
    $this->logger = $logger;
    $this->entityTypeManager = $entity_type_manager;
    $this->viewsExecutableFactory = $viewsExecutableFactory;
  }

  /**
   * {@inheritdoc}
   */
  public function loadView($view_name, $display_id) {
    if (empty($view_name) || '_none' === $view_name || empty($display_id)) {
      return NULL;
    }

    $executable_view = NULL;

    try {
      $view = $this->entityTypeManager
        ->getStorage('view')
        ->load($view_name);
      if ($view) {
        $executable_view = $this->viewsExecutableFactory->get($view);
        $executable_view->setDisplay($display_id);
        $executable_view->initHandlers();
      }
    }
    catch (\Exception $e) {
      $this->logger->error('Exception: @error', ['@error' => $e->getMessage()]);
    }

    return $executable_view;
  }

}
